required_libraries = c("jsonlite")
for (libname in required_libraries) {
    if (!require(libname, character.only = TRUE)) {
        install.packages(libname, dependencies = TRUE)
        library(libname, character.only = TRUE)
    }
}

j1 = read_json("datasets.json")
t1 = read.table(file = 'views_downloads.tsv', sep = '\t', header = TRUE)

columns = c("uuid", "downloads", "views")
df_uuids = data.frame(matrix(ncol = length(columns)))
colnames(df_uuids) = columns

# From t1, read the uuid, count_downloads, and count_views from each dataset.
for (i in 1:nrow(t1)) {
    uuid = t1[[i,1]]
    count_downloads = t1[[i,2]]
    count_views = t1[[i,3]]
    # Store the uuid, count_downloads, and count_views in the data frame, df_uuids.
    df_uuids = rbind(df_uuids, list(uuid, count_downloads, count_views))
}

# From j1, read the uuid from each dataset.
for (i in 1:length(j1)) {
    j_uuid = j1[[i]]$uuid
    posted_date = j1[[i]]$timeline$posted

    # The format of posted_date is "2023-08-25T08:26:19"
    day_of_week = weekdays(as.Date(posted_date, format = "%Y-%m-%dT%H:%M:%S"))
    month = months(as.Date(posted_date, format = "%Y-%m-%dT%H:%M:%S"))
    year = format(as.Date(posted_date, format = "%Y-%m-%dT%H:%M:%S"), "%Y")

    defined_type = j1[[i]]$defined_type
    defined_type_name = j1[[i]]$defined_type_name
    url_public_html = j1[[i]]$url_public_html

    # tryCatch should be used to handle the error when url_public_html is NULL.
    tryCatch({
        revision = unlist(strsplit(url_public_html, "/"))[length(unlist(strsplit(url_public_html, "/")))]
    }, error = function(e) {
        revision = "1"
    })

    tryCatch({
        df_uuids$posted_date[df_uuids$uuid == j_uuid] = posted_date
        df_uuids$day_of_week[df_uuids$uuid == j_uuid] = day_of_week
        df_uuids$month[df_uuids$uuid == j_uuid] = month
        df_uuids$year[df_uuids$uuid == j_uuid] = year
        df_uuids$defined_type[df_uuids$uuid == j_uuid] = defined_type
        df_uuids$defined_type_name[df_uuids$uuid == j_uuid] = defined_type_name
        df_uuids$url_public_html[df_uuids$uuid == j_uuid] = url_public_html
        df_uuids$revision[df_uuids$uuid == j_uuid] = revision
    }, error = function(e) {
        print(i)
        print(j1[[i]])
        print(e)
    })
}

# If posted_date is NA, remove the row.
for (i in 1:2) {
    for (j in 1:nrow(df_uuids)) {
        tryCatch({
            if (is.na(df_uuids[[j,4]])) {
                df_uuids = df_uuids[-j,]
            }
        }, error = function(e) {
            print(j)
        })
    }
}
