required_libraries = c("ggplot2")
for (libname in required_libraries) {
    if (!require(libname, character.only = TRUE)) {
        install.packages(libname, dependencies = TRUE)
        library(libname, character.only = TRUE)
    }
}

source("dataloader.r")

year_month = data.frame(df_uuids$year, df_uuids$month)
year_month_aggr = aggregate(year_month, by=list(year_month$df_uuids.year, year_month$df_uuids.month), FUN = length)
logvec = dlnorm(year_month_aggr$df_uuids.month)
year_month_aggr = cbind(year_month_aggr, logvec)

my_breaks = c()
for ( i in seq(0, 100, by=10) ) { my_breaks = c(my_breaks, i) }
my_breaks = c(my_breaks, 200, 300, 400, 500, 600, 700)

ggplot(year_month_aggr, aes(x = ordered(Group.2, levels=c("January", "February", "March", "April", "May", "June", "July", "August", "September", "October", "November", "December")), y = Group.1, fill=df_uuids.month)) +
    geom_tile(color="black") +
    scale_fill_gradientn(colors = rev(hcl.colors(16, "RdYlBu")), na.value = "white", breaks = my_breaks, trans="log") +
    coord_fixed() +
    geom_text(aes(label = df_uuids.month), size = 3, color="white") +
    labs(title = "Where Do We Come From? What Are We? Where Are We Going?", x = "month", y = "year", fill = "Count") +
    guides(fill = guide_colourbar(barwidth=0.5, barheight=40))

ggsave("heatmap_year_month.png", width = 30, height = 30, units = "cm")
